OpenTravelData (OPTD) POR Data
------------------------------

This directory contains POR (Points Of Reference) date files.
The main data file is named `optd_por_public.csv`, whose master is located
on the [OpenTravelData (OPTD) project on GitHub](https://github.com/opentraveldata/opentraveldata):
[`opentraveldata/optd_por_public.csv`](https://github.com/opentraveldata/opentraveldata/blob/master/opentraveldata/optd_por_public.csv).

The data files are also available from https://transport-search.org/data/optd/por/

A good complementary tool is [GeoBase](https://opentraveldata.github.io/geobases),
a Python-based software able to access to any travel-related data source.

Licensing
---------
The data in this directory and repository are governed by the
[CC-BY-SA license](http://creativecommons.org/licenses/by-sa/3.0/).

